@@ -74,29 +74,27 @@ class AutoCrosswalk(object):
     
     
     def __fix_by(self,by,cols):        
-        if not isinstance(cols,list):
-            raise bg.exceptions.WrongInputTypeException(input_name="cols",
-                                                        provided_input=cols,
-                                                        allowed_inputs=list)
-        
+        """
+        Merge "by" and "cols" such that there are no repeated arguments
+        """
+        bg.sanity_check.check_type(x=cols, allowed=list,name="cols")
+
         if by is None:
             by = cols
-        elif isinstance(by, list):
-            
-            # Exclude elem from cols
-            by = [x for x in by if not bg.tools.isin(a=x, b=cols)]
+
+        bg.sanity_check.check_type(x=by, allowed=(list,str),name="by")
+  
+        if isinstance(by, list):          
+            # Exclude elements from cols in by
+            by = [x for x in by if not x in cols]
             
+            # Add all cols
             by += cols
-        elif isinstance(by, str):
-            
-            if bg.tools.isin(a=by, b=cols):
+        elif isinstance(by, str):            
+            if by in cols:
                 by = cols
             else:            
                 by = cols+[by]
-        else:
-            raise bg.exceptions.WrongInputTypeException(input_name="by",
-                                                        provided_input=by,
-                                                        allowed_inputs=[None, list, str])
         return by
     
     def __fix_W(self,key,key_name,W):
@@ -858,7 +856,6 @@ class AutoCrosswalk(object):
         
         # Find columns to merge by
         merge_cols = list(crosswalk.index.names)
-        merge_cols.sort()
         
         # Fix by
         self.by = self.__fix_by(by=by,cols=merge_cols)
